@@ -39,7 +39,10 @@ import shutil
 import inspect
 from datetime import datetime
 from functools import partial
-from collections import Container
+try:
+    from collections.abc import Container
+except ImportError:
+    from collections import Container
 from contextlib import contextmanager
 import subprocess
 import asyncio
