@@ -20,6 +20,7 @@ import iceprod
 from iceprod.core import dataclasses
 from iceprod.core import constants
 from iceprod.core import functions
+from iceprod.core.exe import Config
 from iceprod.core.resources import sanitized_requirements, rounded_requirements
 from iceprod.core.exe_json import ServerComms
 from iceprod.server import grid
@@ -608,7 +609,8 @@ class condor_direct(grid.BaseGrid):
                 dataset = await self.rest_client.request('GET', f'/datasets/{task["dataset_id"]}')
                 config = await self.rest_client.request('GET', f'/config/{task["dataset_id"]}')
                 dataset_cache[task['dataset_id']] = (dataset, config)
-            config = copy.deepcopy(config)
+            parser = Config(config)
+            config = parser.parseObject(config, {})
 
             task_cfg = None
             for t in config['tasks']:
@@ -764,6 +766,7 @@ class condor_direct(grid.BaseGrid):
         batch_opts = {}
         input_files = list(filelist)
         output_files = []
+        output_remaps = []
         for b in self.queue_cfg['batchopts']:
             if b.lower() == 'requirements':
                 requirements.append(self.queue_cfg['batchopts'][b])
@@ -778,8 +781,10 @@ class condor_direct(grid.BaseGrid):
                         for bb in cfg['steering']['batchsys'][b]:
                             value = cfg['steering']['batchsys'][b][bb]
                             if bb.lower() == 'requirements':
+                                logger.info(f'steering batchsys requirement: {value}')
                                 requirements.append(value)
                             else:
+                                logger.info(f'steering batchsys other: {bb} = {value}')
                                 batch_opts[bb] = value
             if 'task' in cfg['options']:
                 t = cfg['options']['task']
@@ -811,9 +816,9 @@ class condor_direct(grid.BaseGrid):
                                 elif bb.lower() == 'transfer_input_files':
                                     input_files.extend(value.split(','))
                                 elif bb.lower() == 'transfer_output_files':
-                                    output_files.extend(v.strip() for v in value.split(','))
+                                    output_files.extend(value.split(','))
                                 elif bb.lower() == 'transfer_output_remaps':
-                                    output_files.extend(v.split('=',1)[-1].strip() for v in value.split(','))
+                                    output_remaps.extend(value.split(','))
                                 else:
                                     logger.info(f'{task["task_id"]} task batchsys other: {bb}={value}')
                                     batch_opts[bb] = value
@@ -838,6 +843,8 @@ class condor_direct(grid.BaseGrid):
             p('+SpoolOnEvict = False')
             output_files.extend(['iceprod_log.gz', 'iceprod_out.gz', 'iceprod_err.gz'])
             p('transfer_output_files = {}'.format(','.join(output_files)))
+            if output_remaps:
+                p('transfer_output_remaps = "{}"'.format(';'.join(output_remaps)))
 
             # put some info about the task in the classads
             p(f'+IceProdDatasetId = "{task["dataset_id"]}"')
